<?php
/*
Plugin Name: Chick Comic Embedder
Plugin URI: http://dev.efieldguide.com/comic-embedder/
Description: This plugin allows you to embed Jack Chick's great comics into your posts and pages using shortcode.
Version: 1.0
Author: J.D. Grimes
Author URI: http://dev.efieldguide.com/
License: GPL2
*/

/*  Copyright 2013  J.D. Grimes  (email : jdg@dev.efieldguide.com)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2, as 
    published by the Free Software Foundation.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

/****
 * Developers: for information on adding custom CSS styles, see developers.txt
 ****/

/***** Activation *****/

register_activation_hook( __FILE__, 'chickcomic_activation' );
function chickcomic_activation()
{
	/** Add Options **/
	add_option( 'cce_default_comic', '1' );
	add_option( 'cce_default_unavailable', 'random' );
	add_option( 'cce_default_style', 'center' );

	/*
	 Enable custom styles.
	 These files are not overwritten. We create them only if they don't already exist.
	 This allows user's to add their own custom CSS style options.
	*/
	
	if ( !stream_resolve_include_path( dirname( __FILE__ ) . '/custom-styles.php' ) )
	{
		$file = fopen( dirname( __FILE__ ) . '/custom-styles.php', 'w' );
		fwrite( $file, '<?php define( "CHICKCOMIC_CUSTOM_STYLES", FALSE ); /* Change this to "TRUE" to enable custom styles. */ ?>' );
		fclose( $file );
	}
	
	if ( !stream_resolve_include_path( dirname( __FILE__ ) . '/custom-styles.css' ) )
	{
		$file = fopen( dirname( __FILE__ ) . '/custom-styles.css', 'w' );
		fwrite( $file, '/* You can add your own custom CSS styles in this file. See developers.txt for more information. */' );
		fclose( $file );
	}
}

/***** Includes *****/

// Shortcode.
include dirname( __FILE__ ) . '/shortcode.php';

// Settings page.
include dirname( __FILE__ ) . '/options.php';

// Style preview page.
include dirname( __FILE__ ) . '/style-preview.php';

// Custom styles. Avoid giving an error when the plugin is being activated, and this file hasn't been created yet.
if ( in_array( 'chick-comic-embedder/chick-comic-embedder.php', get_option( 'active_plugins' ) ) ) {
	include dirname( __FILE__ ) . '/custom-styles.php';
}


/***** Core Functions *****/

/**
 * Get all available comics.
 * @returns (array)  An array of all comics that are currently available.
 */
function cce_available_comics()
{
	return array(
		// id => name
		'1' => 'This Was Your Life',
		'5' => 'Unloved',
		'6' => 'It\'s A Deal',
		'7' => 'Creator Or Liar?',
		'8' => 'The Choice',
		'9' => 'The Greatest Story Ever Told',
	);
}

/**
 * Get available comic styles.
 * @returns (array)  An array of all available comic styles.
 */
function cce_available_styles()
{
	// Included styles.
	$styles = array(
		'none' => 'None',
		'center' => 'Center',
		'wrap-left' => 'Wrap text (left)',
		'wrap-right' => 'Wrap text (right)',
		'inset-box' => 'Inset Box',
	);	

	// Allow this to be filtered, so developers can add their own style options.
	return apply_filters( 'chickcomic_styles_filter', $styles );
}


/***** Styles *****/

function cce_enqueue_styles()
{
	// Default styles.
	wp_register_style('cce_comics', plugins_url( 'styles.css', __FILE__ ) );
	wp_enqueue_style('cce_comics');
	
	// Custom styles.
	if ( defined( 'CHICKCOMIC_CUSTOM_STYLES' ) && ( 'CHICKCOMIC_CUSTOM_STYLES' == TRUE ) )
	{
		wp_register_style('cce_comics_custom', plugins_url( 'custom-styles.css', __FILE__ ) );
		wp_enqueue_style('cce_comics_custom');
	}
}
add_action('wp_enqueue_scripts', 'cce_enqueue_styles');

?>