<?php

/** Register Shortcode **/
function chickcomic_shortcode($atts)
{
	extract( shortcode_atts( array(
		'comic' => get_option( 'cce_default_comic' ),
		'unavailable' => get_option( 'cce_default_unavailable' ),
		'style' => get_option( 'cce_default_style' ),
	), $atts ) );

	return display_chickcomic( $comic, $unavailable, $style );
}
add_shortcode( 'chickcomic', 'chickcomic_shortcode' );

/**
 * Display a comic. (This is the function used by the shortcode.)
 *
 * @param $id (numeric|string)  The id of the comic | 'random' | 'latest' | The title of a comic.
 * @param $unavailable (string)  The action to take if the asked for comic is unavailable.
 * @param $style (string)  The HTML class to apply to the comic container element.
 *
 * @returns (string|bool)  The HTML for a comic (or FALSE on failure).
 */
function display_chickcomic( $comic = NULL, $unavailable = NULL, $style = NULL )
{
	// Get array of available comics.
	$comics = cce_available_comics();

	// If the $comic isn't set we use the default.
	if ( empty( $comic ) )
	{
		$comic = get_option( 'cce_default_comic' );
	   
	   // If it's set, but not a valid id...
	} elseif ( !isset( $comics[$comic] ) && $comic != 'random' && $comic != 'latest' ) {	
		// Check if it's a comic title. First capitalize the first letter of each word.
		$comic = ucwords( strtolower( $comic ) );
		if ( in_array( $comic, $comics ) )
		{
			$comic = array_search( $comic, $comics );
			
		   // If it's not, then the comic is unavailable.
		} else {
			// If $unavailble isn't set, we use the default.
			if ( empty( $unavailable ) ) {
				$unavailable = get_option( 'cce_default_unavailable' );
			}
	
			switch( $unavailable )
			{
				case 'random':
					$comic = 'random'; break;
				case 'default':
					$comic = get_option( 'cce_default_comic' ); break;
				case 'none':
					return FALSE;
				default:
					$comic = 'random';
			}
		}
	}

	// If we are going to display a random comic, we pick a random one to display.
	if ( $comic == 'random' ) {
		$comic = array_rand( $comics );
	}
	
	// If we are going to display the latest comic.
	if ( $comic == 'latest' ) {
		$comic_file = 'preview';
	} else {
		$comic_file = 'tract_' . $comic;
	}
	
	// Checking what style to give the comic.
	$styles = cce_available_styles();
	if ( empty( $style ) ) {
		$style = get_option( 'cce_default_style' );
	}

	// If we aren't going to give the comic a style.
	if ( $style == 'none' ) {
		$style = '';
	}
	
	// Return the HTML for the comic.
	return '<div class="chickcomic-container '. $style .'">
		<object width="425" height="240">
		<param name="movie" value="http://media.chick.com/'. $comic_file .'.swf"></param>
		<param name="wmode" value="transparent"></param>
		<embed src="http://media.chick.com/'. $comic_file .'.swf" type="application/x-shockwave-flash" wmode="transparent" width="425" height="240"></embed>
		</object></div>';
}

?>